@@ -5,20 +5,21 @@ class Permission(Base):
     @classmethod
     def get_resource_class(cls, client):
         from ..resources.permissions import Permissions
+
         return Permissions(client)
 
     @property
     def id(self):
-        return self._get_property('id')
+        return self._get_property("id")
 
     @property
     def resource(self):
-        return self._get_property('resource')
+        return self._get_property("resource")
 
     @property
     def description(self):
-        return self._get_property('description')
+        return self._get_property("description")
 
     @property
     def granted(self):
-        return self._get_property('granted')
+        return self._get_property("granted")
